summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/NotationStaff.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/notation/NotationStaff.h')
-rw-r--r--src/gui/editors/notation/NotationStaff.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/gui/editors/notation/NotationStaff.h b/src/gui/editors/notation/NotationStaff.h
index f58e77d..b941ac0 100644
--- a/src/gui/editors/notation/NotationStaff.h
+++ b/src/gui/editors/notation/NotationStaff.h
@@ -136,14 +136,14 @@ public:
/**
* Assign suitable coordinates to the elements on the staff,
* based entirely on the layout X and Y coordinates they were
* given by the horizontal and vertical layout processes.
*
* This is necessary because the sprites that are being positioned
* may have been created either after the layout process completed
* (by renderElements) or before (by the previous renderElements
* call, if the sprites are unchanged but have moved) -- so
* neither the layout nor renderElements can authoritatively set
* their final positions.
*
* This method also updates the selected-ness of any elements it
@@ -197,7 +197,7 @@ public:
* elements). Pass movedOnly as true to indicate that elements
* have not changed but only been repositioned, for example as a
* consequence of a modification on another staff that caused a
- * relayout.
+ * retqlayout.
*/
virtual void markChanged(timeT from = 0,
timeT to = 0,
@@ -223,7 +223,7 @@ public:
/**
* Insert time signature at x-coordinate \a x.
*/
- virtual void insertTimeSignature(double layoutX,
+ virtual void insertTimeSignature(double tqlayoutX,
const TimeSignature &timeSig);
/**
@@ -234,7 +234,7 @@ public:
/**
* Insert repeated clef and key at start of new line, at x-coordinate \a x.
*/
- virtual void insertRepeatedClefAndKey(double layoutX, int barNo);
+ virtual void insertRepeatedClefAndKey(double tqlayoutX, int barNo);
/**
* Delete all repeated clefs and keys.
@@ -270,7 +270,7 @@ public:
Accidentals::NoAccidental) const;
/**
* Find the NotationElement whose layout x-coord is closest to x,
* without regard to its y-coord.
*
* If notesAndRestsOnly is true, will return the closest note
@@ -289,7 +289,7 @@ public:
int proximityThreshold = 10);
/**
* Find the NotationElement "under" the given layout x-coord,
* without regard to its y-coord.
*
* Also returns the clef and key in force at the given coordinates.
@@ -301,7 +301,7 @@ public:
* Draw a note on the staff to show an insert position prior to
* an insert.
*/
- virtual void showPreviewNote(double layoutX, int heightOnStaff,
+ virtual void showPreviewNote(double tqlayoutX, int heightOnStaff,
const Note &note, bool grace);
/**
@@ -396,7 +396,7 @@ protected:
* Returns true if the item at the given iterator appears to have
* moved horizontally without the spacing around it changing.
*
* In practice, calculates the offset between the intended layout
* and current canvas coordinates of the item at the given
* iterator, and returns true if this offset is equal to those of
* all other following iterators at the same time as well as the
@@ -412,7 +412,7 @@ protected:
/**
* Prepare a painter to draw an object of logical width w at
* layout-x coord x, starting at offset dx into the object, by
* setting the painter's clipping so as to crop the object at the
* right edge of the row if it would otherwise overrun. The
* return value is the amount of the object visible on this row
@@ -423,7 +423,7 @@ protected:
* This function calls painter.save(), and the caller must call
* painter.restore() after use.
*/
- virtual double setPainterClipping(TQPainter *, double layoutX, int layoutY,
+ virtual double setPainterClipping(TQPainter *, double tqlayoutX, int tqlayoutY,
double dx, double w, LinedStaffCoords &coords,
FitPolicy policy);
@@ -473,8 +473,8 @@ protected:
TQPainter *m_printPainter;
- enum BarStatus { UnRendered = 0, Rendered, Positioned };
- typedef std::map<int, BarStatus> BarStatusMap;
+ enum BartqStatus { UnRendered = 0, Rendered, Positioned };
+ typedef std::map<int, BartqStatus> BarStatusMap;
BarStatusMap m_status;
std::pair<int, int> m_lastRenderCheck;
bool m_ready;
@@ -136,14 +136,14 @@ public:
/**
* Assign suitable coordinates to the elements on the staff,
- * based entirely on the layout X and Y coordinates they were
- * given by the horizontal and vertical layout processes.
+ * based entirely on the tqlayout X and Y coordinates they were
+ * given by the horizontal and vertical tqlayout processes.
*
* This is necessary because the sprites that are being positioned
@@ -136,14 +136,14 @@ public:
*
* This is necessary because the sprites that are being positioned
- * may have been created either after the layout process completed
+ * may have been created either after the tqlayout process completed
* (by renderElements) or before (by the previous renderElements
* call, if the sprites are unchanged but have moved) -- so
@@ -136,14 +136,14 @@ public:
* (by renderElements) or before (by the previous renderElements
* call, if the sprites are unchanged but have moved) -- so
- * neither the layout nor renderElements can authoritatively set
+ * neither the tqlayout nor renderElements can authoritatively set
* their final positions.
*
@@ -270,7 +270,7 @@ public:
Accidentals::NoAccidental) const;
/**
- * Find the NotationElement whose layout x-coord is closest to x,
+ * Find the NotationElement whose tqlayout x-coord is closest to x,
* without regard to its y-coord.
*
@@ -289,7 +289,7 @@ public:
int proximityThreshold = 10);
/**
- * Find the NotationElement "under" the given layout x-coord,
+ * Find the NotationElement "under" the given tqlayout x-coord,
* without regard to its y-coord.
*
@@ -396,7 +396,7 @@ protected:
* moved horizontally without the spacing around it changing.
*
- * In practice, calculates the offset between the intended layout
+ * In practice, calculates the offset between the intended tqlayout
* and current canvas coordinates of the item at the given
* iterator, and returns true if this offset is equal to those of
@@ -412,7 +412,7 @@ protected:
/**
* Prepare a painter to draw an object of logical width w at
- * layout-x coord x, starting at offset dx into the object, by
+ * tqlayout-x coord x, starting at offset dx into the object, by
* setting the painter's clipping so as to crop the object at the
* right edge of the row if it would otherwise overrun. The